Scriptname ZWP_V6_AliasScript extends ReferenceAlias  

;-------------------------------------------------------------------------
String Property AliasState Auto
Actor PlayerActor
ObjectReference WPAlchemyBenchRef
ObjectReference UninstallThrowAliasRef
ObjectReference UninstallCatchAliasRef
ObjectReference PhialAliasRef
ObjectReference RestoreAliasRef
;-------------------------------------------------------------------------
Event OnInit()
	PlayerActor = Game.GetPlayer()
	WPAlchemyBenchRef = (GetOwningQuest().GetAlias(24) as ReferenceAlias).GetRef()
	UninstallThrowAliasRef = (GetOwningQuest().GetAlias(21) as ReferenceAlias).GetRef()
	UninstallCatchAliasRef = (GetOwningQuest().GetAlias(22) as ReferenceAlias).GetRef()
	PhialAliasRef = (GetOwningQuest().GetAlias(12) as ReferenceAlias).GetRef()
	RestoreAliasRef = (GetOwningQuest().GetAlias(25) as ReferenceAlias).GetRef()
	GoToState(AliasState)
EndEvent

;---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
; WHITE PHIAL MONITORING
;---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
FormList Property ZWP_Phials Auto
GlobalVariable Property ZWP_Restored Auto
Spell Property ZWP_WhitePhialPower Auto
MiscObject RepairedPhial
MiscObject RestoredPhial
;-------------------------------------------------------------------------
STATE PlayerState
;-------------------------------------------------------------------------
Event OnBeginState()
	AddInventoryEventFilter(ZWP_Phials)
	RepairedPhial = (ZWP_Phials.GetAt(0) as MiscObject)
	RestoredPhial = (ZWP_Phials.GetAt(1) as MiscObject)
EndEvent

Event OnItemAdded(Form akBaseItem, int aiItemCount, ObjectReference akItemReference, ObjectReference akSourceContainer)
IF (ZWP_Restored.GetValue() >= 0)
	If (akBaseItem == RepairedPhial)
		PlayerActor.AddSpell(ZWP_WhitePhialPower, False)
	ElseIf (akBaseItem == RestoredPhial) 
		ZWP_Restored.SetValue(1)
		GetOwningQuest().SetStage(10)
		PlayerActor.AddItem(RepairedPhial,1,True)
		PlayerActor.RemoveItem(RestoredPhial,1,True)
		Game.IncrementSkill("Alchemy")
	EndIf
ELSE
	(GetOwningQuest() as ZWP_V6_QuestScript).StartPhial(True, akBaseItem as Potion)
ENDIF
EndEvent

Event OnItemRemoved(Form akBaseItem, int aiItemCount, ObjectReference akItemReference, ObjectReference akDestContainer)
	If (akBaseItem == RepairedPhial)
		Game.GetPlayer().RemoveSpell(ZWP_WhitePhialPower)
	ElseIf !(akDestContainer == None)
		akDestContainer.RemoveItem(akBaseItem, aiItemCount,True, UninstallThrowAliasRef)
	EndIf
EndEvent
ENDSTATE

;-------------------------------------------------------------------------
FormList Property ZWP_FormListAllow Auto
FormList Property ZWP_FormListDeny Auto
Keyword Property VendorItemFood Auto
Message Property ZWP_WhitePhialMessage Auto
Message Property ZWP_WhitePhialPatchMessage Auto
;ObjectReference PhialRef
;-------------------------------------------------------------------------
STATE PhialState
;-------------------------------------------------------------------------
Event OnItemAdded(Form akBaseItem, int aiItemCount, ObjectReference akItemReference, ObjectReference akSourceContainer)
IF akSourceContainer == PlayerActor
	IF ((akBaseItem as Potion) && !(akBaseItem.HasKeyword(VendorItemFood)) && !(ZWP_FormListDeny.HasForm(akBaseItem))) || (ZWP_FormListAllow.HasForm(akBaseItem))
		If (akBaseItem == CurrentPhialPotion()) && (PhialAliasRef.GetItemCount(CurrentPhialPotion()) > 1)
			PhialAliasRef.RemoveItem(akBaseItem, aiItemCount, True, akSourceContainer)
			Debug.MessageBox("The White Phial is already full.")
			UnregisterForUpdateGameTime()
		ElseIf (akBaseItem == CurrentPhialPotion()) && (PhialAliasRef.GetItemCount(CurrentPhialPotion()) == 1)
			UnregisterForUpdateGameTime()
		ElseIf (ZWP_Restored.GetValue() == 0)
			PhialAliasRef.RemoveItem(akBaseItem, aiItemCount, True, akSourceContainer)
			Debug.MessageBox("The White Phial can only refill\n with one type of liquid.")
		Else
			RealignChoice(akBaseItem, aiItemCount, akSourceContainer)
		EndIf
	ELSEIF !(ZWP_FormListDeny.HasForm(akBaseItem)) && ((akBaseItem as Potion) || (akBaseItem as Ingredient)) && (ZWP_Restored.GetValue() == 1)
		Int PatchChoiceInt = ZWP_WhitePhialPatchMessage.Show()
		If PatchChoiceInt == 0
			ZWP_FormListAllow.AddForm(akBaseItem)
			RealignChoice(akBaseItem, aiItemCount, akSourceContainer)
		Else
			ZWP_FormListDeny.AddForm(akBaseItem)
			PhialAliasRef.RemoveItem(akBaseItem, aiItemCount, True, akSourceContainer)
		EndIf
	ELSE
		PhialAliasRef.RemoveItem(akBaseItem, aiItemCount, True, akSourceContainer)
		If (ZWP_Restored.GetValue() == 0)
			Debug.MessageBox("The White Phial can only be filled\n with one type of liquid.")
		Else
			Debug.MessageBox("The White Phial can only be filled with liquids.")
		EndIf
	ENDIF
ENDIF
EndEvent

Event OnItemRemoved(Form akBaseItem, int aiItemCount, ObjectReference akItemReference, ObjectReference akDestContainer)
IF akDestContainer == Game.GetPlayer()
	If (akBaseItem == CurrentPhialPotion()) && (GetRef().GetItemCount(CurrentPhialPotion()) == 0)
		Int RegisterTime = (18+((CurrentPhialPotion().GetGoldValue() as Int)/30))
		RegisterForSingleUpdateGameTime(RegisterTime)
	EndIf
ENDIF
EndEvent

Event OnUpdateGameTime()
	(GetOwningQuest() as ZWP_V6_QuestScript).Refill()
EndEvent
ENDSTATE

Function RealignChoice(Form akBaseItem, int aiItemCount, ObjectReference akSourceContainer)
	Int ChoiceInt = ZWP_WhitePhialMessage.Show()
	If ChoiceInt == 0
		GetRef().RemoveItem(akBaseItem, aiItemCount, True, akSourceContainer)
	Else
		Form RemovingPotion = CurrentPhialPotion()
		(GetOwningQuest() as ZWP_V6_QuestScript).Realign(akBaseItem)
		PhialAliasRef.RemoveItem(akBaseItem, (GetRef().GetItemCount(akBaseItem) - 1), True, akSourceContainer)
		PhialAliasRef.RemoveItem(RemovingPotion, GetRef().GetItemCount(RemovingPotion), True, akSourceContainer)
	EndIf
EndFunction

Form Function CurrentPhialPotion()
	Return (GetOwningQuest() as ZWP_V6_QuestScript).CurrentPotion
EndFunction

;---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
; UNISTALLING & RESTORING
;---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
;-------------------------------------------------------------------------
STATE UninstallState
;-------------------------------------------------------------------------
	Event OnActivate(ObjectReference akTriggerRef)
		If akTriggerRef == PlayerActor
			UninstallThrowAliasRef.RemoveItem(ZWP_Phials, UninstallThrowAliasRef.GetItemCount(ZWP_Phials), True, UninstallCatchAliasRef)
			WHILE !(Utility.IsInMenuMode())
			ENDWHILE
			WHILE (Utility.IsInMenuMode())
			ENDWHILE
			UninstallCatchAliasRef.RemoveItem(ZWP_Phials, UninstallCatchAliasRef.GetItemCount(ZWP_Phials), True, UninstallThrowAliasRef)
		EndIf	
	EndEvent
ENDSTATE

;-------------------------------------------------------------------------
Furniture Property ZWP_Restore_Workbench Auto
ObjectReference RestoreBench
;-------------------------------------------------------------------------
STATE RestorerState
;-------------------------------------------------------------------------
	Event OnBeginState()
		RestoreBench = (WPAlchemyBenchRef.PlaceAtMe(ZWP_Restore_Workbench) as ObjectReference)
		RestoreBench.Disable()
	EndEvent

	Event OnActivate(ObjectReference akTriggerRef)
		If akTriggerRef == PlayerActor
			If PlayerActor.GetActorValue("Alchemy") >= 75
				RegisterForAnimationEvent(PlayerActor, "IdleFurnitureExit")
				RestoreBench.Enable()
				Utility.Wait(0.1)
				RestoreBench.Activate(akTriggerRef,True)
			Else
				Debug.Notification("You don't have the skill to restore the White Phial.")
			EndIf
		EndIf
	EndEvent

	Event OnAnimationEvent(ObjectReference akSource, string asEventName)
		If asEventName == "IdleFurnitureExit"
			UnRegisterForAnimationEvent(PlayerActor, "IdleFurnitureExit")
			Utility.Wait(0.1)
			RestoreBench.Disable()
		Endif
	EndEvent
ENDSTATE